# To simulate 10 values from a Poisson distribution
# of parameter lambda = 25
sim_10 <- rpois(10, lambda = 25)
# To simulate 100 values from a Poisson distribution
# of parameter lambda = 25
sim_100 <- rpois(100, lambda = 25)

# Generalization: a function to simulate n values from
# a Poisson distribution of parameter lambda = 25
sim_poisson <- function(n) {
  rpois(n = n, lambda = 25)
}

# lapply will take a list and a function
# and return a list containing the results
# of applying the function on each item in the input list
# We use it to generate random samples of different sizes from 
# a Poisson distribution of parameter lambda = 25
poisson_sims <- lapply(
  list(5, 10, 100, 1000, 10000, 100000),
  sim_poisson)

# We should have 6 vectors in the list, of growing sizes
str(poisson_sims)

# Example, extracting the one of size 10 (the second one):
poisson_sims[[2]]

# A function that generates a bar plot
# with size of data as label of the x axis
plot_sim <- function(dat) {
  barplot(table(dat), xlab = paste("n=", length(dat)))
}

# Opening a pdf "device" to save our bar plots
# Be careful: this will silently overwrite a possible
# pre-existing file with the same name
pdf("poisson.pdf")
par(mfcol = c(3, 2))
# We could manually plot the bar plots for each simulation:
#plot_sim(poisson_sims[[1]])
#plot_sim(poisson_sims[[2]])
#plot_sim(poisson_sims[[3]])
#plot_sim(poisson_sims[[4]])
#plot_sim(poisson_sims[[5]])
#plot_sim(poisson_sims[[6]])
# But this is a good opportunity to show
# how to do the same with a "for" loop:
for (i in 1:6) {
  # In the loop body (delimited by curly braces)
  # variable i takes the successive values in 1:6
  # We can apply our plotting function on each simulation
  # by using i to access it in the list of simulations
  plot_sim(poisson_sims[[i]])
}
dev.off()
# (Use an external program to visualize the resulting pdf file)